@@ -9,7 +9,7 @@ CMesh CVoronoiSmoothing::Smooth(CSurface &arSurf, bool aSuperSmooth, int aSmooth
     //begin smooth part 1, collecting all the cpoints from the faces on the surf
     SetPinPout( );
     UpdateInput( );
-    mSurf.CreateSurface(false);
+    mSurf.CreateSurface();
     CalculatePointNeighbours();
     //begin smooth  part 2, adding new points between the cpoints by aSmoothFactor
     UpdatePoutPin();
@@ -69,7 +69,7 @@ void CVoronoiSmoothing::SetPinPout()
 void CVoronoiSmoothing::UpdateInput()
 {
     vector<CPoint> new_points;
-    vector<coord_t> new_quan;
+    vector<normal_float> new_quan;
     for (auto & it : mOutPoints) {
         new_points.push_back(mSurf.GetInputPoints()[it]);
         new_quan.push_back(mSurf.GetUVcoords()[it]);
@@ -110,7 +110,7 @@ void CVoronoiSmoothing::Stage2ModifyPoints()
     size_t c_point3;
 
     vector<CPoint> new_points;
-    vector<coord_t> new_quan;
+    vector<normal_float> new_quan;
     size_t p_out_size = mOutPoints.size();
     size_t p_in_size = p_out_size + mInPoints.size();
     mInPoints.clear();
@@ -127,7 +127,7 @@ void CVoronoiSmoothing::Stage2ModifyPoints()
 }
 
 void CVoronoiSmoothing::FindPairPoints(size_t aCPoint1, size_t aCPoint2, vector<size_t> &mInPoints, vector<size_t> &mOutPoints, size_t mOutPointsSize, size_t mInPointsSize,
-                                       const CSurfaceFace &arFace, vector<CPoint> &arNewPoints, vector<coord_t> &arNewQuan, size_t &arIndex)
+                                       const CSurfaceFace &arFace, vector<CPoint> &arNewPoints, vector<normal_float> &arNewQuan, size_t &arIndex)
 {
     size_t c_point3;
     for (auto & f_index : mPointNeighbours[aCPoint1])
@@ -153,7 +153,7 @@ void CVoronoiSmoothing::FindPairPoints(size_t aCPoint1, size_t aCPoint2, vector<
     }
 }
 
-void CVoronoiSmoothing::AddPointsAlt(vector<size_t> &arPVec, vector<CPoint> &arNewPoints, vector<coord_t> &arNewQuan,
+void CVoronoiSmoothing::AddPointsAlt(vector<size_t> &arPVec, vector<CPoint> &arNewPoints, vector<normal_float> &arNewQuan,
                                      size_t &arNewIndex, size_t aCPoint1, size_t aCPoint2, size_t aCPoint3)
 {
     arPVec.push_back(arNewIndex);
@@ -170,7 +170,7 @@ void CVoronoiSmoothing::Stage2AddPoints(size_t aSmoothFactor)
     size_t p_out_size = mOutPoints.size();
     size_t p_in_size = p_out_size + mInPoints.size();
     vector<CPoint> new_points;
-    vector<coord_t> new_quan;
+    vector<normal_float> new_quan;
     mInPoints.clear();
     mOutPoints.clear();
     size_t new_index = 0; // the index for the new point to be added
@@ -191,7 +191,7 @@ void CVoronoiSmoothing::Stage2AddPoints(size_t aSmoothFactor)
     CleanDoublePointsVorn(new_points, new_quan, mInPoints, mOutPoints);
 }
 
-void CVoronoiSmoothing::AddPoints(vector<size_t> * apPVec, vector<CPoint> * apNewPoints, vector<coord_t> * apNewQuan, size_t * apNewIndex, size_t aCPoint1, size_t aCPoint2, int aSmoothFactor)
+void CVoronoiSmoothing::AddPoints(vector<size_t> * apPVec, vector<CPoint> * apNewPoints, vector<normal_float> * apNewQuan, size_t * apNewIndex, size_t aCPoint1, size_t aCPoint2, int aSmoothFactor)
 {
     coord_t x, y, z;
     for (int i = 1; i <= aSmoothFactor; i++){
@@ -200,12 +200,12 @@ void CVoronoiSmoothing::AddPoints(vector<size_t> * apPVec, vector<CPoint> * apNe
         y = (mSurf.GetInputPoints()[aCPoint1].Y() * (aSmoothFactor + 1 - i) + mSurf.GetInputPoints()[aCPoint2].Y() * i) / (aSmoothFactor+1);
         z = (mSurf.GetInputPoints()[aCPoint1].Z() * (aSmoothFactor + 1 - i) + mSurf.GetInputPoints()[aCPoint2].Z() * i) / (aSmoothFactor+1);
         (*apNewPoints).push_back(CPoint(x, y, z));
-        (*apNewQuan).push_back((mSurf.GetUVcoords()[aCPoint1] * (aSmoothFactor + 1 - i) + mSurf.GetUVcoords()[aCPoint2] * i) / (aSmoothFactor + 1));
+        (*apNewQuan).push_back((mSurf.GetUVcoords()[aCPoint1] * (aSmoothFactor + 1 - i) + mSurf.GetUVcoords()[aCPoint2] * i) / (aSmoothFactor+1));
         (*apNewIndex)++;
     }
 }
 
-void CVoronoiSmoothing::CleanDoublePointsVorn(vector<CPoint>& arNewPoints, vector<coord_t>& arNewQuan, vector<size_t>& arNewIn, vector<size_t>& arNewOut)
+void CVoronoiSmoothing::CleanDoublePointsVorn(vector<CPoint>& arNewPoints, vector<normal_float>& arNewQuan, vector<size_t>& arNewIn, vector<size_t>& arNewOut)
 {
     vector<CSurfacePoint> data;
     data.clear();
