@@ -33,13 +33,13 @@ namespace vivid
         void Stage2ModifyPoints();
         // TODO: Way too many fucking arguments, at least clean it up a bit by making them class variables. Rename the supersmooth functions as well just for better readability
         void FindPairPoints(size_t aCPoint1, size_t aCPoint2, std::vector<size_t> &arPIn, std::vector<size_t> &arPOut, size_t aPOutSize, size_t aPInSize,
-                            const CSurfaceFace &arFace, std::vector<CPoint> &arNewPoints, std::vector<coord_t> &arNewQuan, size_t &arIndex);
-        void AddPointsAlt(std::vector<size_t> &arPVec, std::vector<CPoint> &arNewPoints, std::vector<coord_t> &arNewQuan,
+                            const CSurfaceFace &arFace, std::vector<CPoint> &arNewPoints, std::vector<normal_float> &arNewQuan, size_t &arIndex);
+        void AddPointsAlt(std::vector<size_t> &arPVec, std::vector<CPoint> &arNewPoints, std::vector<normal_float> &arNewQuan,
                           size_t &arNewIndex, size_t aCPoint1, size_t aCPoint2, size_t aCPoint3); // Adds points between every pair by aSmoothFactor
         void Stage2AddPoints(size_t aSmoothFactor);
-        void AddPoints(std::vector<size_t> * apPVec, std::vector<CPoint> * apNewPoints, std::vector<coord_t> * apNewQuan,
+        void AddPoints(std::vector<size_t> * apPVec, std::vector<CPoint> * apNewPoints, std::vector<normal_float> * apNewQuan,
                        size_t * apNewIndex, size_t aCPoint1, size_t aCPoint2, int aSmoothFactor); // Adds points between every pair by aSmoothFactor
-        void CleanDoublePointsVorn(std::vector<CPoint>& arNewPoints, std::vector<coord_t>& arNewQuan,
+        void CleanDoublePointsVorn(std::vector<CPoint>& arNewPoints, std::vector<normal_float>& arNewQuan,
                                    std::vector<size_t>& arNewIn, std::vector<size_t>& arNewOut); // Handles the reallocation after RemoveDoublesVornInput
         // Part 3
         void MakeMask();
