@@ -19,6 +19,7 @@ namespace vivid
 
         CSurfacePoint() {};
         CSurfacePoint(const CPoint& arPoint, coord_t aUVcoord, bool aIsIn): mPoint(arPoint), UVcoord(aUVcoord), mMaskIsTrue(aIsIn) {}
+        inline bool operator < (const CSurfacePoint &arObj) {return mPoint < arObj.mPoint;}
     };
 
 // For the cleaning stage
@@ -44,7 +45,7 @@ namespace vivid
         // Input Data:
         std::vector<CPoint> mInputPoints = {};
         std::vector<bool> mCreationMask = {};
-        std::vector<coord_t> mUVcoords = {};
+        std::vector<normal_float> mUVcoords = {};
 
         // PreProcessing Data
         std::pair<CPoint, CPoint> mBoxPair = {}; // Holds min and max boxPoints for ComputeVoronoi
@@ -61,17 +62,16 @@ namespace vivid
         std::vector<CPoint> FindContainingBox(); // Find Box dimensions for RunVorn.
 
         // Handle Input Sub-Methods
-        void PreProcessPoints(vector<CSurfacePoint> &arPoints);                 // Centering, scaling, adding noise.
+        void PreProcessPoints(vector<CSurfacePoint> &arPoints, coord_t aNoiseDisplacement);   // Centering, scaling, adding noise.
         void CleanDoubleInputPoints(vector<CSurfacePoint> &arPoints);           // remove all the double input points
 
-        // TODO: Should be in util, even better should be typedef with min 0. and max 1.
-        std::vector<coord_t>& NormColorField(std::vector<coord_t>& arColorField, coord_t aVMin, coord_t aVMax); // normalize the values to be between 0 and 1, uses Vmin and Vmax
-
         //vorn function:
         void RunVorn();
 
         // Cleaning Sub-Methods
         void CleanFaces();        // clean the unneeded faces(by mCreationMask)
+        vector<CSurfaceFace> TriangulizeFace(const CSurfaceFace &arFace);
+        void NormalizeFace(CSurfaceFace& arTriangleFace); // normalize face to face correct direction
         void CleanPoints();       // removes all the unused points
         void CleanEdges();        // cleans faces that are out of the box radius (happens as a result of too little points as input)
         void CleanDoublePoints(); // remove all the double face points from the model
@@ -83,20 +83,19 @@ namespace vivid
          * @param[in] arMask a boolean mask of true and false points
          * @param[in] arColorField a vector containing the color field of each point
          * @param[in] aVMin the minimum value in arColorField, anything below will be set to aVMin
-         * @param[in] aVMin the maximum value in arColorField, anything below will be set to aVMax
+         * @param[in] aVMax the maximum value in arColorField, anything below will be set to aVMax
+         * @param[in] aNoiseDisplacement the Voronoi algorithm struggles with equidistant point data, a small noise displacement improves algorithm speed
          */
         CSurface(const std::vector<CPoint> &arInputPoints, const std::vector<bool> &arMask,
-                 std::vector<coord_t> &arColorField, coord_t aVMin, coord_t aVMax);
+                 std::vector<normal_float> &arColorField, normal_float aVMin, normal_float aVMax, coord_t aNoiseDisplacement = 0.001);
         /**
          * CSurface Copy-Constructor
          */
         CSurface(const CSurface &surf);
-        // operator =
-
         /**
          * Create the surfaces using the input data
          */
-        void CreateSurface(bool aPostProcessing = true);
+        void CreateSurface();
 
         /**
          * Convert the CSurface object to CMesh object
@@ -104,7 +103,7 @@ namespace vivid
          * @param[in] aAlpha the alpha to assign to the new mesh
          * @returns CMesh converted mesh
          */
-        CMesh ToMesh(const string& arLabel, coord_t aAlpha) const;
+        CMesh ToMesh(const string& arLabel, normal_float aOpacity) const;
 
         std::vector<CSurfacePoint> RemoveDoublesVornInput(std::vector<CSurfacePoint>& arData);
 
@@ -112,28 +111,13 @@ namespace vivid
         // Used primarily in deprecated smoothing
         inline const std::vector<CPoint>& GetInputPoints() const { return mInputPoints; }
         inline const std::vector<bool>& GetMask() { return mCreationMask; }
-        inline const std::vector<coord_t>& GetUVcoords() { return mUVcoords; }
+        inline const std::vector<normal_float>& GetUVcoords() { return mUVcoords; }
         inline const std::vector<CSurfaceFace>& GetFaces() const { return mSurfFaces; }
         inline const CVoronoi& GetVoronoiData() const { return mVoronoi; }
 
         inline void SetInputPoints(const std::vector<CPoint> &arPoints) { mInputPoints = arPoints; }
         inline void SetMask(const std::vector<bool> &arMask) { mCreationMask = arMask; }
-        inline void SetUVcoords(const std::vector<coord_t> &arUVcoords) { mUVcoords = arUVcoords; }
-
-
-        void WhatAreTheseThingsElad() {
-            cout << mVoronoi.mData.GetAllVolumes().size() << endl;
-            cout << mVoronoi.mData.GetAllArea().size() << endl;
-            cout << mVoronoi.mData.GetAllCM().size() << endl;
-            cout << mVoronoi.mData.GetAllCellFaces().size() << endl;
-            cout << mVoronoi.mData.GetPointNo() << endl;
-            // Useless data:
-            cout << mVoronoi.mData.GetSelfIndex().size() << endl;
-            cout << mVoronoi.mData.GetSentProcs().size() << endl;
-            cout << mVoronoi.mData.GetSentPoints().size() << endl;
-        } //?
-
-
+        inline void SetUVcoords(const std::vector<normal_float> &arUVcoords) { mUVcoords = arUVcoords; }
     };
 
 } // namespace vivid
