@@ -3,12 +3,12 @@
 #include "ModelBuilder/Model.h"
 #include "ModelBuilder/Shapes.h"
 #include "ModelBuilder/SurfByFunc.h"
-/*include "ImportAndExport/FBXImportExport.h"*/
 #include "ModelBuilder/Surface.h"
 #include "Point.h"
 #include "AssimpImportExport.h"
 #include "DataToImage.h"
 #include "Model.h"
+#include "PointCloud.h"
 #include <map>
 #include <assimp/Importer.hpp>
 #include <assimp/DefaultLogger.hpp>
@@ -30,14 +30,14 @@ const std::string TEST_OUTPUT_PATH = "./tests/test_models/";
 /* Test basic shapes creation, add them to a Model and export to OBJ. */
 int ShapesTest()
 {
-    cout << "Basic Test:" << endl;
+    Log(LOG_INFO, "Basic Test:");
 
     CModel model;
     // Some 3D viewers are centering the 3D models and change direction. this sets the center
-    CMesh sphere = CreateSphereMesh(CPoint(0.0, 0.0, 0.0), 5, 20, 20, 0.1, 0.8, "sphere1" );
-    CMesh arrow_x = CreateArrowMesh( CPoint(0,0,0), CPoint(0,5,0), 0.15, 0.4, 0.8, 0.6, "arrowX");
-    CMesh box = CreateBoxMesh(CPoint(4,0,0), CPoint(5,3,4), 0.5, 0.4, "Box");
-    CMesh cube = CreateCubeMesh(CPoint(-4,0,0), 3, 0.5, 0.4, "Cube");
+    CMesh sphere = CreateSphereMesh(CPoint(0.0, 0.0, 0.0), 5, 20, 20, "purple", 0.8, "sphere1" );
+    CMesh arrow_x = CreateArrowMesh( CPoint(0,0,0), CPoint(0,5,0), 0.15, 0.1, "green", 0.6, "arrowX");
+    CMesh box = CreateBoxMesh(CPoint(4,0,0), CPoint(5,3,4), "red", 0.4, "Box");
+    CMesh cube = CreateCubeMesh(CPoint(-4,0,0), 3, "yellow", 0.4, "Cube");
     pair<CLines, CLines> grid = CreateGrid(100, 10);
     vector<CModelComponent> list = {sphere, arrow_x, box, cube, grid.first, grid.second};
     model.AddMeshes(list);
@@ -106,9 +106,9 @@ int ParametricSurfByFuncTest()
 /* Test surf functionality with cube */
 int CubeSurfTests()
 {
-    cout << "Cube Test:" << endl;
+    Log(LOG_INFO, "Cube Test:");
 
-    vector<CPoint> points; vector<coord_t> quan; vector<bool> mask;
+    vector<CPoint> points; vector<normal_float> quan; vector<bool> mask;
 
     for (int i = 2; i >= -2; i -= 2) { // make the vornoi input points, a 3d grid for all combination optionts for 2, 0, -2
         for (int j = 2; j >= -2; j -= 2) {
@@ -125,16 +125,14 @@ int CubeSurfTests()
     CModel model;
     CSurface surf = CSurface(points, mask, quan, *min_element(quan.begin(), quan.end() ), *max_element(quan.begin(), quan.end()) );
     surf.CreateSurface();
-//    cerr << "Initiating Copy Constructor" << endl;
+//    cerr << "Initiating Copy Constructor");
 //    CSurface surf_copy = CSurface(surf);
     CMesh mesh = surf.ToMesh("vivid_3d_obj", 1.0);
-    mesh.SetClm("Red");
+    mesh.SetColor("Red");
     //mesh.Reduce(0.3, 0.3);
     mesh.ExportToObj(TEST_OUTPUT_PATH + "/Cube");
-    CMesh mesh2 = CreateBoxMesh(CPoint(4,0,0), CPoint(5,3,4), 0.5, 0.4, "Box");
-    mesh2.SetClm("Green");
-    CMesh mesh3 = CreateBoxMesh(CPoint(-4,0,0), CPoint(5,3,4), 0.5, 0.4, "Box");
-    mesh3.SetClm("Blue");
+    CMesh mesh2 = CreateBoxMesh(CPoint(4,0,0), CPoint(5,3,4), "green", 0.4, "Box");
+    CMesh mesh3 = CreateBoxMesh(CPoint(-4,0,0), CPoint(5,3,4), "blue", 0.4, "Box");
     vector<CModelComponent> meshes = {mesh2, mesh3};
     model.AddMesh(mesh2);
     model.ExportToObj(TEST_OUTPUT_PATH + "/CubeShape");
@@ -148,8 +146,7 @@ int ColorMapTest()
     vector<string> colors = {"Red", "Blue", "Green", "Purple", "Yellow", "Cyan", "White", "Black"};
     vector<CPoint> loc = {{0,0,0}, {1,0,0}, {2,0,0},{0,0,1},{1,0,1},{2,0,1},{0,0,2},{1,0,2}};
     for (int i = 0; i < colors.size(); i++) {
-        CMesh box = CreateCubeMesh(loc[i]*3,0.5,1,1,colors[i]);
-        box.SetClm(colors[i]);
+        CMesh box = CreateCubeMesh(loc[i]*3,0.5,colors[i],1,colors[i]);
         model.AddMesh(box);
     }
     model.ExportToObj(TEST_OUTPUT_PATH + "/ColorsTest");
@@ -160,11 +157,11 @@ int ColorMapTest()
 /* Test surf functionality by cubic 3D pyramid (with square base) */
 int PyramidSmoothTest()
 {
-    cout << "Pyramid Test:" << endl;
+    Log(LOG_INFO, "Pyramid Test:");
 
     vector<CPoint> points;
     vector<bool> mask;
-    vector<coord_t> quan;
+    vector<normal_float> quan;
     coord_t Vmin, Vmax;
     vector<double> temp;
     int a = 0;
@@ -190,24 +187,19 @@ int PyramidSmoothTest()
             }
         }
     }
-    cout << quan.size() << endl;
-    Vmax = 0 ; //*max_element(quan.begin(), quan.end());
-    Vmin = 0 ;//*min_element(quan.begin(), quan.end());
 
-    CSurface smooth1 = CSurface(points, mask, quan, *min_element( quan.begin(), quan.end() ), *max_element( quan.begin(), quan.end()) );
-    smooth1.CreateSurface();
-    //smooth1.WhatAreTheseThingsElad();
+    Vmax = 0.0; //*max_element(quan.begin(), quan.end());
+    Vmin = 0.0;//*min_element(quan.begin(), quan.end());
+    CPointCloud pyramid_points = CPointCloud(points, quan, Vmin, Vmax, 1.0, "vivid_assimp_test");
+//    CSurface smooth1 = CSurface(points, mask, quan, Vmin, Vmax);
+//    smooth1.CreateSurface();
     //CSurface surf_copy = CSurface(smooth1);
-    CMesh mesh1 = smooth1.ToMesh("vivid_assimp_test", 1);
+    CMesh mesh1 = pyramid_points.CreateVoronoiSurface(mask, 0.0001);
     mesh1.LaplacianSmooth(10);
 //    //mesh1.Reduce(0.3, 0.5);
-    cout << TEST_OUTPUT_PATH + "PyramidAssimpAnim" << endl;
-    CAnimation anim1 = CAnimation(CModel(mesh1));
-    anim1.SetRotateAnim(0, CPoint(6.28, 0, 0));
 //    anim1.SetScaleAnim(0,CPoint(3,3,3));
 //    anim1.SetMoveAnim(0, CPoint(50, -50, 20));
-    vivid::CAssimpExport::AnimationExporter(anim1, "gltf2", TEST_OUTPUT_PATH + "PyramidAssimpAnim");
-//    mesh1.Export(TEST_OUTPUT_PATH + "PyramidAssimpNewMat", "obj");
+    mesh1.Export(TEST_OUTPUT_PATH + "PyramidAssimpNewMat", "obj");
 //    mesh1.ExportToObj(TEST_OUTPUT_PATH + "PyramidVivid");
 //    CSurface smooth3 = CSurface(points, mask, quan, *min_element( quan.begin(), quan.end() ), *max_element( quan.begin(), quan.end()) );
 //    smooth3.CreateSurface();
@@ -242,9 +234,9 @@ int PyramidSmoothTest()
 
 int RunMedicaneTest()
 {
-    cout << "Medicane Test:" << endl;
+    Log(LOG_INFO, "Medicane Test:");
     ModelData nova;
-    cout << "Running VIVID" << endl;
+    Log(LOG_INFO, "Running VIVID");
 
     nova = ReadBin(DATA_MODEL_PATH + "medicane.bin");
     vector<CPoint> points (nova.points.size());
@@ -255,11 +247,10 @@ int RunMedicaneTest()
     CSurface surf = CSurface(points, nova.mask, nova.quan, -15.1, 1.51);
     surf.CreateSurface();
     //surf.Smooth(false, 1);
-    cout << "Convert to Mesh" << endl;
+    Log(LOG_INFO, "Convert to Mesh");
     CMesh mesh = surf.ToMesh("SurfMedicane", 1);
     //mesh.SubdivideLargeFaces(4);
 //        mesh.RemovePointyFaces(20);
-    mesh.CalculatePointsNeighbours();
     mesh.LaplacianSmooth(10, 0.7, 0);
 //    mesh.LaplacianSmooth(50, 0.4, 0.7);
 //    mesh.RemovePointyFaces();
@@ -274,9 +265,9 @@ int RunMedicaneTest()
 /* Test the Elad RunVorn bug and the pointy faces bugs */
 int RunSupernovaTests()
 {
-    cout << "Black Hole Test:" << endl;
+    Log(LOG_INFO, "Black Hole Test:");
 //    vector<ModelData> data (7);
-//    cout << "Loading Data" << endl;
+//    Log(LOG_INFO, "Loading Data");
 ////    data[0] = ReadBin(DATA_MODEL_PATH + "Supernova-0.bin");
 //    data[0] = ReadBin(DATA_MODEL_PATH + "Supernova-1_5.bin");
 //    data[1] = ReadBin(DATA_MODEL_PATH + "Supernova-2_5.bin");
@@ -288,7 +279,7 @@ int RunSupernovaTests()
     vector<coord_t> why = {0, 1.5, -2.5, -6, -7. - 10., -15.};
     ModelData nova;
     CModel nova_model;
-    cout << "Running VIVID" << endl;
+    Log(LOG_INFO, "Running VIVID");
 
     nova = ReadBin(DATA_MODEL_PATH + "medicane.bin");
     vector<CPoint> points (nova.points.size());
@@ -307,11 +298,10 @@ int RunSupernovaTests()
         CSurface surf = CSurface(points, nova.mask, nova.quan, -15.1, 1.51);
         surf.CreateSurface();
         //surf.Smooth(false, 1);
-        cout << "Convert to Mesh" << endl;
+        Log(LOG_INFO, "Convert to Mesh");
         CMesh mesh = surf.ToMesh("Surf" + to_string(i), .7);
         //mesh.SubdivideLargeFaces(4);
 //        mesh.RemovePointyFaces(20);
-        mesh.CalculatePointsNeighbours();
         mesh.LaplacianSmooth(6, 0.7, 0);
         mesh.LaplacianSmooth(50, 0.4, 0.7);
         //mesh.RemovePointyFaces();
@@ -324,8 +314,8 @@ int RunSupernovaTests()
 }
 
 int RemovePointyFacesTest() {
-    cout << "Remove Pointy Faces Test:" << endl;
-    cout << "Loading Data" << endl;
+    Log(LOG_INFO, "Remove Pointy Faces Test:");
+    Log(LOG_INFO, "Loading Data");
 ////    data[0] = ReadBin(DATA_MODEL_PATH + "Supernova-0.bin");
 //    data[0] = ReadBin(DATA_MODEL_PATH + "Supernova-1_5.bin");
 //    data[1] = ReadBin(DATA_MODEL_PATH + "Supernova-2_5.bin");
@@ -341,13 +331,13 @@ int RemovePointyFacesTest() {
     CSurface surf = CSurface(points, nova.mask, nova.quan, 0, 0);
     surf.CreateSurface();
     //surf.Smooth(false, 1);
-    cout << "Convert to Mesh" << endl;
+    Log(LOG_INFO, "Convert to Mesh");
     CMesh mesh = surf.ToMesh("pointytest", .7);
     mesh.ExportToObj(TEST_OUTPUT_PATH + "/Supernova_no_processing");
     mesh.SubdivideLargeFaces();
     mesh.SubdivideLargeFaces();
     mesh.SubdivideLargeFaces();
-    cout << mesh.GetFaces().size() << endl;
+    Log(LOG_INFO, to_string(mesh.GetFaces().size()));
     mesh.RemovePointyFaces();
     mesh.LaplacianSmooth(20, 0.7, 0);
     mesh.ExportToObj(TEST_OUTPUT_PATH + "/Supernova_smooth_1");
@@ -465,49 +455,50 @@ int CubeAnimationTest()
     vector<string> colors = {"Red", "Blue", "Green", "Purple", "Yellow", "Cyan", "White", "Black"};
     vector<CPoint> loc = {{0,0,0}, {1,0,0}, {2,0,0},{0,0,1},{1,0,1},{2,0,1},{0,0,2},{1,0,2}};
     for (int i = 0; i < colors.size(); i++) {
-        CMesh box = CreateCubeMesh(loc[i]*3,0.5,1,1,colors[i]);
-        box.SetClm(colors[i]);
+        CMesh box = CreateCubeMesh(loc[i]*3,0.5,colors[i],1,colors[i]);
         models.push_back((CModel(box)));
     }
     //CStopMotionAnimation anim = CStopMotionAnimation(models, 3);
     CAnimation anim = CAnimation(models);
     anim.SetDuration(150);
-//    anim.SetRotateAnim(0, CPoint(2.3,0,1));
-//    anim.SetRotateAnim(3, CPoint(0,2.3,1));
-//    anim.SetRotateAnim(2, CPoint(2.3,0,1));
-//    anim.SetRotateAnim(5, CPoint(2.3,2.3,0));
-//    anim.SetMoveAnim(2,CPoint(3,3,3));
-//    anim.SetMoveAnim(7,CPoint(3,3,3));
+    anim.SetRotateAnim(0, CPoint(2.3,0,1));
+    anim.SetRotateAnim(3, CPoint(0,2.3,1));
+    anim.SetRotateAnim(2, CPoint(2.3,0,1));
+    anim.SetRotateAnim(5, CPoint(2.3,2.3,0));
+    anim.SetMoveAnim(2,CPoint(3,3,3));
+    anim.SetMoveAnim(5,CPoint(3,3,3));
     anim.SetScaleAnim(6, CPoint(2,2,2));
     anim.SetScaleAnim(1, CPoint(5,0,0));
     CStopMotionAnimation SManim = CStopMotionAnimation(anim, 2);
-    CAssimpExport::AnimationExporter(anim, "gltf2", TEST_OUTPUT_PATH + "/CubeAnimationTest");
+    SManim.Export( TEST_OUTPUT_PATH + "/CubeAnimationTest", "gltf2");
+    //AssimpExport::AnimationExporter(anim, "gltf2", TEST_OUTPUT_PATH + "/CubeAnimationTest");
     return EXIT_SUCCESS;
 }
 int main()
 {
 //    assimpTest(TEST_OUTPUT_PATH + "/sat_gal_anim.gltf");
     int ret_value = EXIT_SUCCESS;
-//    cout << "MedicaneTestTest" << endl;
+//    Log(LOG_INFO, "MedicaneTestTest");
 //    ret_value =RunMedicaneTest();
 //    if ( EXIT_SUCCESS != ret_value ) return ret_value;
-//    cout << "ParametricSurfByFuncTest" << endl;
+//    Log(LOG_INFO, "ParametricSurfByFuncTest");
 //    ret_value = ParametricSurfByFuncTest();
 //    if ( EXIT_SUCCESS != ret_value ) return ret_value;
-//    cout << "Testing All Shapes" << endl;
+//    Log(LOG_INFO, "Testing All Shapes");
 //    ret_value = ShapesTest();
 //    if ( EXIT_SUCCESS != ret_value ) return ret_value;
-//    cout << "Cube" << endl;
+//    Log(LOG_INFO, "Cube");
+//    ret_value = CubeSurfTests();
 //    if ( EXIT_SUCCESS != ret_value ) return ret_value;
-//    cout << "Colors" <<endl;
+//    Log(LOG_INFO, "Colors");
 //    ret_value = ColorMapTest();
 //    if ( EXIT_SUCCESS != ret_value) return ret_value;
-//    cout << "Pyramid" << endl;
-//    ret_value = PyramidSmoothTest();
-//    if ( EXIT_SUCCESS != ret_value ) return ret_value;
-    cout << "Cube Animation" << endl;
-    ret_value = CubeAnimationTest();
+    Log(LOG_INFO, "Pyramid");
+    ret_value = PyramidSmoothTest();
     if ( EXIT_SUCCESS != ret_value ) return ret_value;
+//    cout << "Cube Animation" << endl;
+//    ret_value = CubeAnimationTest();
+//    if ( EXIT_SUCCESS != ret_value ) return ret_value;
 //    ret_value = RemovePointyFacesTest();
 //    if ( EXIT_SUCCESS != ret_value ) return ret_value;
     return EXIT_SUCCESS;
